set more off

capture log close
log using diGiovanni_Levchenko_Comovement_AEJmacro_TableB1, text replace

/*
    Date: July 13, 2009
    
    Program: this file reproduces Table B1 of di Giovanni and Levchenko, 
             "Putting the Parts Together: Trade, Vertical Linkages, and 
             Business Cycle Comovement", AEJ: Macro.
 */

clear
set mem 1g
set matsize 10000

use ../Data/aggregsdata
gen bitrade_gdp = exp(lbitrade_gdp)

* Generate pctiles for trade ratio

local i = 1
foreach X of numlist .5 1.25 2.5 5 95 97.5 98.75 99.5{
    egen bitrade_gdp_p`i' = pctile(bitrade_gdp), p(`X')
    egen lbitrade_gdp_p`i' = pctile(lbitrade_gdp), p(`X')
    local i = `i'+1
}   

* Regressions

xi: areg corr_growth_gdp bitrade_gdp i.ifscode1, abs(ifscode2) r
outreg bitrade_gdp using trimreg_trade, replace se 10pct nolab rdec(3) coef

foreach X of numlist 1/4{
    local Y = 8-`X'+1
    xi: areg corr_growth_gdp bitrade_gdp i.ifscode1 if bitrade_gdp>bitrade_gdp_p`X' & bitrade_gdp<bitrade_gdp_p`Y', abs(ifscode2) r
    outreg bitrade_gdp using trimreg_trade, append se 10pct nolab rdec(3) coef
}

xi: areg corr_growth_gdp lbitrade_gdp i.ifscode1, abs(ifscode2) r
outreg lbitrade_gdp using trimreg_ltrade, replace se 10pct nolab rdec(3) coef

foreach X of numlist 1/4{
    local Y = 8-`X'+1
    xi: areg corr_growth_gdp lbitrade_gdp i.ifscode1 if lbitrade_gdp>lbitrade_gdp_p`X' & lbitrade_gdp<lbitrade_gdp_p`Y', abs(ifscode2) r
    outreg lbitrade_gdp using trimreg_ltrade, append se 10pct nolab rdec(3) coef
}

log close
